PRD is the mean ratio divided by the mean ratio weighted by sale price. It is a measure of vertical equity in assessment. Vertical equity means that properties at different levels of the income distribution should be similarly assessed.
PRD centers slightly above 1 and has a generally accepted value of between 0.98 and 1.03, as defined in the IAAO Standard on Ratio Studies Section 9.2.7. Higher PRD values indicate regressivity in assessment.
NOTE: The IAAO recommends trimming outlier ratios before calculating PRD, as it is extremely sensitive to large outliers. PRD is being deprecated in favor of PRB, which is less sensitive to outliers and easier to interpret.
Usage
prd(assessed, sale_price, na.rm = FALSE)
prd_ci(assessed, sale_price, nboot = 100, alpha = 0.05, na.rm = FALSE)
prd_met(x)Arguments
- assessed
A numeric vector of assessed values. Must be the same length as
sale_price.- sale_price
A numeric vector of sale prices. Must be the same length as
assessed.- na.rm
Default FALSE. A boolean value indicating whether or not to remove NA values. If missing values are present but not removed the function will output NA.
- nboot
Default 100. Number of iterations to use to estimate the output statistic confidence interval.
- alpha
Default 0.05. Numeric value indicating the confidence interval to return. 0.05 will return the 95% confidence interval.
- x
Numeric vector of sales ratio statistic(s) to check against IAAO/Quintos standards.